==> haskell-comonad-5.0.9-95-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-comonad.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 comonad
version:              5.0.9
visibility:           public
id:                   comonad-5.0.9-Ii5hgdheJL2Zm3d3qSYJo
key:                  comonad-5.0.9-Ii5hgdheJL2Zm3d3qSYJo
license:              BSD-3-Clause
copyright:
    Copyright (C) 2008-2014 Edward A. Kmett,
    Copyright (C) 2004-2008 Dave Menendez

maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/comonad/
synopsis:             Comonads
description:          Comonads.
category:             Control, Comonads
abi:                  fa0716d569b4bafad30a6a6306ce64f2
exposed:              True
exposed-modules:
    Control.Comonad Control.Comonad.Env Control.Comonad.Env.Class
    Control.Comonad.Hoist.Class Control.Comonad.Identity
    Control.Comonad.Store Control.Comonad.Store.Class
    Control.Comonad.Traced Control.Comonad.Traced.Class
    Control.Comonad.Trans.Class Control.Comonad.Trans.Env
    Control.Comonad.Trans.Identity Control.Comonad.Trans.Store
    Control.Comonad.Trans.Traced Data.Functor.Composition

import-dirs:          /usr/lib/ghc-9.4.8/site-local/comonad-5.0.9
library-dirs:         /usr/lib/ghc-9.4.8/site-local/comonad-5.0.9
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/comonad-5.0.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-comonad
hs-libraries:         HScomonad-5.0.9-Ii5hgdheJL2Zm3d3qSYJo
depends:
    base-4.17.2.1 containers-0.6.7
    distributive-0.6.2.1-59IAOHM1chG6SQlfccy7lE
    indexed-traversable-0.1.4-6I34tNI5leL7QXgWHpiE2g
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C transformers-0.5.6.2
    transformers-compat-0.7.2-F1TSDgHxVH372cWL2D3XnQ

haddock-interfaces:   /usr/share/doc/haskell-comonad/html/comonad.haddock
haddock-html:         /usr/share/doc/haskell-comonad/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-comonad-5.0.9-96-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-comonad.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 comonad
version:              5.0.9
visibility:           public
id:                   comonad-5.0.9-DbocoRZxFWPanrrsdFCv7
key:                  comonad-5.0.9-DbocoRZxFWPanrrsdFCv7
license:              BSD-3-Clause
copyright:
    Copyright (C) 2008-2014 Edward A. Kmett,
    Copyright (C) 2004-2008 Dave Menendez

maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/comonad/
synopsis:             Comonads
description:          Comonads.
category:             Control, Comonads
abi:                  2dac5c6f5ce867e2584c635b3b61b3ef
exposed:              True
exposed-modules:
    Control.Comonad Control.Comonad.Env Control.Comonad.Env.Class
    Control.Comonad.Hoist.Class Control.Comonad.Identity
    Control.Comonad.Store Control.Comonad.Store.Class
    Control.Comonad.Traced Control.Comonad.Traced.Class
    Control.Comonad.Trans.Class Control.Comonad.Trans.Env
    Control.Comonad.Trans.Identity Control.Comonad.Trans.Store
    Control.Comonad.Trans.Traced Data.Functor.Composition

import-dirs:          /usr/lib/ghc-9.4.8/site-local/comonad-5.0.9
library-dirs:         /usr/lib/ghc-9.4.8/site-local/comonad-5.0.9
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/comonad-5.0.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-comonad
hs-libraries:         HScomonad-5.0.9-DbocoRZxFWPanrrsdFCv7
depends:
    base-4.17.2.1 containers-0.6.7
    distributive-0.6.2.1-H2SZC2c21mWIPC9Ih6JR9X
    indexed-traversable-0.1.4-BQcRr3W4PxWCuaKGpNnbu1
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C transformers-0.5.6.2
    transformers-compat-0.7.2-F1TSDgHxVH372cWL2D3XnQ

haddock-interfaces:   /usr/share/doc/haskell-comonad/html/comonad.haddock
haddock-html:         /usr/share/doc/haskell-comonad/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
